==> rust-fd-find_8.6.0.orig.tar.gz: fd-find-8.6.0/CONTRIBUTING.md <==
## Contributing to *fd*

**Thank you very much for considering to contribute to this project!**

We welcome any form of contribution:

  * New issues (feature requests, bug reports, questions, ideas, ...)
  * Pull requests (documentation improvements, code improvements, new features, ...)

**Note**: Before you take the time to open a pull request, please open a ticket first. This will
give us the chance to discuss any potential changes first.

## Add an entry to the changelog

If your contribution changes the behavior of `fd` (as opposed to a typo-fix
in the documentation), please update the [`CHANGELOG.md`](CHANGELOG.md) file
and describe your changes. This makes the release process much easier and
therefore helps to get your changes into a new `fd` release faster.

The top of the `CHANGELOG` contains a *"unreleased"* section with a few
subsections (Features, Bugfixes, …). Please add your entry to the subsection
that best describes your change.

Entries follow this format:
```
- Short description of what has been changed, see #123 (@user)
```
Here, `#123` is the number of the original issue and/or your pull request.
Please replace `@user` by your GitHub username.

## Important links

  * [Open issues](https://github.com/sharkdp/fd/issues)
  * [Open pull requests](https://github.com/sharkdp/fd/pulls)
  * [Development section in the README](https://github.com/sharkdp/fd#development)
  * [fd on crates.io](https://crates.io/crates/fd-find)
  * [LICENSE-APACHE](https://github.com/sharkdp/fd/blob/master/LICENSE-APACHE) and [LICENSE-MIT](https://github.com/sharkdp/fd/blob/master/LICENSE-MIT)

==> rust-fd-find_10.3.0.orig.tar.gz: fd-find-10.3.0/CONTRIBUTING.md <==
## Contributing to *fd*

**Thank you very much for considering to contribute to this project!**

We welcome any form of contribution:

  * New issues (feature requests, bug reports, questions, ideas, ...)
  * Pull requests (documentation improvements, code improvements, new features, ...)

**Note**: Before you take the time to open a pull request, please open a ticket first. This will
give us the chance to discuss any potential changes first.

## Add an entry to the changelog

If your contribution changes the behavior of `fd` (as opposed to a typo-fix
in the documentation), please update the [`CHANGELOG.md`](CHANGELOG.md#upcoming-release) file
and describe your changes. This makes the release process much easier and
therefore helps to get your changes into a new `fd` release faster.

The top of the `CHANGELOG` contains an *"Upcoming release"* section with a few
subsections (Features, Bugfixes, …). Please add your entry to the subsection
that best describes your change.

Entries follow this format:
```
- Short description of what has been changed, see #123 (@user)
```
Here, `#123` is the number of the original issue and/or your pull request.
Please replace `@user` by your GitHub username.

## Important links

  * [Open issues](https://github.com/sharkdp/fd/issues)
  * [Open pull requests](https://github.com/sharkdp/fd/pulls)
  * [Development section in the README](https://github.com/sharkdp/fd#development)
  * [fd on crates.io](https://crates.io/crates/fd-find)
  * [LICENSE-APACHE](https://github.com/sharkdp/fd/blob/master/LICENSE-APACHE) and [LICENSE-MIT](https://github.com/sharkdp/fd/blob/master/LICENSE-MIT)
